@@ -1,8 +1,8 @@
-#  File R/ergm.utility.R in package ergm, part of the
-#  Statnet suite of packages for network analysis, https://statnet.org .
+#  File R/ergm.utility.R in package ergm, part of the Statnet suite of packages
+#  for network analysis, https://statnet.org .
 #
-#  This software is distributed under the GPL-3 license.  It is free,
-#  open source, and has the attribution requirements (GPL Section 7) at
+#  This software is distributed under the GPL-3 license.  It is free, open
+#  source, and has the attribution requirements (GPL Section 7) at
 #  https://statnet.org/attribution .
 #
 #  Copyright 2003-2025 Statnet Commons
@@ -347,3 +347,87 @@ check_ABI <- once(function(client = "ergm", lib  = "ergm", action = getOption("e
     }else TRUE
   }else TRUE
 })
+
+# Useful shorthands
+logit <- qlogis
+expit <- plogis
+
+# TODO: Document and move to statnet.common.
+
+`%[f]%` <- function(x, y) if (is.function(y)) x[y(x)] else x[y]
+
+`%[f]%<-` <- function(x, y, value) replace(x, y, value)
+
+`%[!f]%` <- function(x, y) if (is.function(y)) x[!y(x)] else x[!y]
+
+`%[!f]%<-` <- function(x, y, value) {
+  replace(x,
+          if (is.function(y)) !y(x)
+          else if (is.logical(y)) !y
+          else -y,
+          value)
+}
+
+# Evaluate RHS substituting LHS for ., then use the result to index
+# LHS.
+`%[.]%` <- function(x, y) {
+  x[eval.parent(do.call(substitute, list(substitute(y), list(. = x))))]
+}
+
+# Note: This tries to guess whether to subset the RHS by comparing
+# lengths. This may not be a good heuristic in all cases, so should
+# not be relied on.
+`%[.]%<-` <- function(x, y, value) {
+  i <- eval.parent(do.call(substitute, list(substitute(y), list(. = x))))
+  if (length(value) > length(seq_along(x)[i])) value <- value[i]
+  x[i] <- value
+  x
+}
+
+`%[.,]%<-` <- function(x, y, value) {
+  i <- eval.parent(do.call(substitute, list(substitute(y), list(. = x))))
+  if (length(value) > length(seq_len(dim(x)[1L])[i])) value <- value[i]
+  x[i, ] <- value
+  x
+}
+
+`%[,.]%<-` <- function(x, y, value) {
+  i <- eval.parent(do.call(substitute, list(substitute(y), list(. = x))))
+  if (length(value) > length(seq_len(dim(x)[2L])[i])) value <- value[i]
+  x[, i] <- value
+  x
+}
+
+
+`%[.|.]%<-` <- function(x, y, value) {
+  i <- eval.parent(do.call(substitute, list(substitute(y), list(. = x))))
+  if (length(value) > length(seq_len(dim(x)[2L])[i])) value <- value[i]
+  x[, i] <- x[i, ] <- value
+  x
+}
+
+`%[.,.]%<-` <- function(x, y, value) {
+  i <- eval.parent(do.call(substitute, list(substitute(y), list(. = x))))
+  if (!is.null(dim(value)) && dim(value)[2L] > length(seq_len(dim(x)[2L])[i]))
+    value <- value[i, i]
+  x[i, i] <- value
+  x
+}
+
+rowcolnames <- function(x, ...) {
+  rownames <- rownames(x, ...)
+  colnames <- colnames(x, ...)
+  stopifnot(identical(rownames, colnames))
+
+  rownames
+}
+
+`rowcolnames<-` <- function(x, value) {
+  colnames(x) <- rownames(x) <- value
+  x
+}
+
+split_len <- function(x, l) {
+  stopifnot(length(x) == sum(l))
+  unname(split(x, factor(rep.int(seq_along(l), l), levels = seq_along(l))))
+}
