@@ -1,8 +1,8 @@
-/*  File src/CD.c.template.do_not_include_directly.h in package ergm, part of the
- *  Statnet suite of packages for network analysis, https://statnet.org .
+/*  File src/CD.c.template.do_not_include_directly.h in package ergm, part of
+ *  the Statnet suite of packages for network analysis, https://statnet.org .
  *
- *  This software is distributed under the GPL-3 license.  It is free,
- *  open source, and has the attribution requirements (GPL Section 7) at
+ *  This software is distributed under the GPL-3 license.  It is free, open
+ *  source, and has the attribution requirements (GPL Section 7) at
  *  https://statnet.org/attribution .
  *
  *  Copyright 2003-2025 Statnet Commons
@@ -15,22 +15,22 @@
 *****************/
 
 /*****************
- void DISPATCH_CD_wrapper
+ void ETYPE(CD_wrapper)
 
  Wrapper for a call from R.
 
  and don't forget that tail -> head
 *****************/
-SEXP DISPATCH_CD_wrapper(SEXP stateR,
+SEXP ETYPE(CD_wrapper)(SEXP stateR,
                   // MCMC settings
                   SEXP eta, SEXP samplesize, 
                   SEXP CDparams,
                   SEXP verbose){
   GetRNGstate();  /* R function enabling uniform RNG */
-  DISPATCH_ErgmState *s = DISPATCH_ErgmStateInit(stateR, 0);
+  ETYPE(ErgmState) *s = ETYPE(ErgmStateInit)(stateR, 0);
 
-  DISPATCH_Model *m = s->m;
-  DISPATCH_MHProposal *MHp = s->MHp;
+  ETYPE(Model) *m = s->m;
+  ETYPE(MHProposal) *MHp = s->MHp;
 
   CD_UNDOS_ALLOC;
   double *extraworkspace = R_calloc(m->n_stats, double);
@@ -39,7 +39,7 @@ SEXP DISPATCH_CD_wrapper(SEXP stateR,
   memset(REAL(sample), 0, asInteger(samplesize)*m->n_stats*sizeof(double));
 
   SEXP status;
-  if(MHp) status = PROTECT(ScalarInteger(DISPATCH_CDSample(s,
+  if(MHp) status = PROTECT(ScalarInteger(ETYPE(CDSample)(s,
                                                     REAL(eta), REAL(sample), asInteger(samplesize), INTEGER(CDparams), CD_UNDOS_PASS, extraworkspace,
                                                     asInteger(verbose))));
   else status = PROTECT(ScalarInteger(MCMC_MH_FAILED));
@@ -49,7 +49,7 @@ SEXP DISPATCH_CD_wrapper(SEXP stateR,
   SET_VECTOR_ELT(outl, 0, status);
   SET_VECTOR_ELT(outl, 1, sample);
 
-  DISPATCH_ErgmStateDestroy(s);  
+  ETYPE(ErgmStateDestroy)(s);
   PutRNGstate();  /* Disable RNG before returning */
   UNPROTECT(3);
   return outl;
@@ -57,7 +57,7 @@ SEXP DISPATCH_CD_wrapper(SEXP stateR,
 
 
 /*********************
- void DISPATCH_CDSample
+ void ETYPE(CDSample)
 
  Using the parameters contained in the array eta, obtain the
  network statistics for a sample of size samplesize.  burnin is the
@@ -66,12 +66,12 @@ SEXP DISPATCH_CD_wrapper(SEXP stateR,
  networks in the sample.  Put all the sampled statistics into
  the networkstatistics array. 
 *********************/
-MCMCStatus DISPATCH_CDSample(DISPATCH_ErgmState *s,
+MCMCStatus ETYPE(CDSample)(ETYPE(ErgmState) *s,
                         double *eta, double *networkstatistics, 
 			int samplesize, int *CDparams,
                       CD_UNDOS_RECEIVE, double *extraworkspace,
                         int verbose){
-  DISPATCH_Model *m = s->m;
+  ETYPE(Model) *m = s->m;
 
   int staken=0;
     
@@ -94,7 +94,7 @@ MCMCStatus DISPATCH_CDSample(DISPATCH_ErgmState *s,
   unsigned int i=0, sattempted=0;
   while(i<samplesize){
     
-    if(DISPATCH_CDStep(s, eta, networkstatistics, CDparams, &staken, CD_UNDOS_PASS, extraworkspace,
+    if(ETYPE(CDStep)(s, eta, networkstatistics, CDparams, &staken, CD_UNDOS_PASS, extraworkspace,
 		verbose)!=MCMC_OK)
       return MCMC_MH_FAILED;
 
@@ -123,7 +123,7 @@ MCMCStatus DISPATCH_CDSample(DISPATCH_ErgmState *s,
 /*********************
  void MetropolisHastings
 
- In this function, eta is a m->n_stats-vector just as in DISPATCH_CDSample,
+ In this function, eta is a m->n_stats-vector just as in ETYPE(CDSample),
  but now networkstatistics is merely another m->n_stats-vector because
  this function merely iterates nsteps=CDparams[0] times through the Markov
  chain, keeping track of the cumulative change statistics along
@@ -131,15 +131,15 @@ MCMCStatus DISPATCH_CDSample(DISPATCH_ErgmState *s,
  the networkstatistics vector.  In other words, this function 
  essentially generates a sample of size one
 *********************/
-MCMCStatus DISPATCH_CDStep(DISPATCH_ErgmState *s,
+MCMCStatus ETYPE(CDStep)(ETYPE(ErgmState) *s,
                       double *eta, double *networkstatistics,
                       int *CDparams, int *staken,
                       CD_UNDOS_RECEIVE, double *extraworkspace,
                       int verbose){
 
-  DISPATCH_Network *nwp = s->nwp;
-  DISPATCH_Model *m = s->m;
-  DISPATCH_MHProposal *MHp = s->MHp;
+  ETYPE(Network) *nwp = s->nwp;
+  ETYPE(Model) *m = s->m;
+  ETYPE(MHProposal) *MHp = s->MHp;
   
   unsigned int unsuccessful=0, ntoggled=0;
 
